smf/smfservermodule/smfclient/client/smfgallery_p.h
changeset 14 a469c0e6e7fb
parent 10 77a56c951f86
--- a/smf/smfservermodule/smfclient/client/smfgallery_p.h	Mon Jun 07 11:43:45 2010 +0100
+++ b/smf/smfservermodule/smfclient/client/smfgallery_p.h	Wed Jun 23 19:51:49 2010 +0530
@@ -24,11 +24,13 @@
  * QLocalserver for rest of the platforms
  * Note:- only symbian client-server impl is provided at the moment
  **/
+#ifndef SMFGALLERY_P_H
+#define SMFGALLERY_P_H
 
 #include "smfprovider.h"
-#include "smfclientglobal.h"
-#include "smfglobal.h"
-#include "smfobserver.h"
+#include "SmfClientGlobal.h"
+#include "smfGlobal.h"
+#include "SmfObserver.h"
 
 class SmfProvider;
 
@@ -37,7 +39,7 @@
 #include <QDateTime>
 #include <QStringList>
 
-#include "smfobserver.h"
+#include "SmfObserver.h"
 #include "smfgallery.h"
 #ifdef Q_OS_SYMBIAN
 class CSmfClientSymbian;
@@ -54,33 +56,44 @@
   ~SmfGalleryPrivate();
   
   /**
    * Get the picture listing asynchronously.
    * The picturesAvailable() signal is emitted with SmfPictureList once the pictures have arrived.
    * When the list is big user can specify the page number and per page item data.
    * If not supplied by the user default values are used.
+	 * @param names the subject or any keywords to be used to filter albums with that name
+	 * @param user the user whose albums are requested 
    * @param pageNum Page number to download, SMF_FIRST_PAGE denotes fresh query.
    * @param perPage Item per page, default is SMF_ITEMS_PER_PAGE
    */
-  void pictures(int pageNum=SMF_FIRST_PAGE,int perPage=SMF_ITEMS_PER_PAGE);
+	void albums(QStringList names, SmfContact* user, int pageNum=SMF_FIRST_PAGE,int perPage=SMF_ITEMS_PER_PAGE);
+
 
   /**
-   * Returns a user title/caption for the picture
+	 * Get the picture listing asynchronously.
+	 * The picturesAvailable() signal is emitted with SmfPictureList once the pictures have arrived.
+	 * When the list is big user can specify the page number and per page item data.
+	 * If not supplied by the user default values are used.
+	 * @param albums album(s) whose pictures are being requested
+	 * @param pageNum Page number to download, SMF_FIRST_PAGE denotes fresh query.
+	 * @param perPage Item per page, default is SMF_ITEMS_PER_PAGE
    */
-  QString description(SmfPicture& picture); // A user title or caption, maybe?
+	void pictures(SmfPictureAlbumList albums, int pageNum=SMF_FIRST_PAGE,int perPage=SMF_ITEMS_PER_PAGE);
 
   /**
 	 * Upload an image.Implemented as slot to connect to UI controls more easily
 	 * uploadFinished() signal is emitted with the success value of the upload
 	 * @param image the image to be uploaded
+	 * @param album the optional destination album name 
 	 */
-   void upload(SmfPicture* image) ;
+	void upload(SmfPicture* image, SmfPictureAlbum* album=NULL) ;
 
 	/**
 	 * Upload an list image.Implemented as slot to connect to UI controls more easily
 	 * uploadFinished() signal is emitted with the success value of the upload
 	 * @param images the list image to be uploaded
+	 * @param album the optional destination album name 
 	 */
-   void upload(SmfPictureList* images) ;
+	void upload(SmfPictureList* images, SmfPictureAlbum* album=NULL) ;
 
   /**
    * Posts a comment for an image. uploadFinished() signal is emitted
@@ -89,13 +102,18 @@
    * @param comment Comment to post
    */
    void postComment(SmfPicture image, SmfComment comment) ;
-   //from smfobserver
+	
+	/** from smfobserver */
    void resultsAvailable(QByteArray result,SmfRequestTypeID opcode,SmfError error);
+	
+	
 private:
 	  SmfProvider* m_baseProvider;
 	  //serialized byte array of provider+other info to be sent to the server
 	  //The order:- SmfProvider then params in order of their appearance in fn
 	  QByteArray m_serializedDataToServer;
+	  //serialized xtra info, order of serialization follows order of param
+	  QByteArray m_xtraInfoSerialized;
 	#ifdef Q_OS_SYMBIAN
 	  CSmfClientSymbian* m_SmfClientPrivate;
 	  friend class CSmfClientSymbian;
@@ -106,13 +124,15 @@
 	  bool m_connected;
 	  SmfGallery* m_gallery;
 	  SmfPictureList* m_picList;
+	  int m_xtraInfoFlag;
+	  int m_pageInfoFlag;
 	 void writeLog(QString log) const{};
 
 };
+#endif
 
 
 
 
 
 
-
@@ -54,33 +56,44 @@
   
   /**
-   * Get the picture listing asynchronously.
-   * The picturesAvailable() signal is emitted with SmfPictureList once the pictures have arrived.
+	 * Get the album listing asynchronously.
+	 * The albumsAvailable() signal is emitted with SmfPictureAlbumList once the albums have arrived.
    * When the list is big user can specify the page number and per page item data.
    * If not supplied by the user default values are used.